# Project Authors
This project was developed at Miami University of Ohio under the guidance of Dr. Samer Khamaiseh.

## Project Director
- Dr. Samer Khamaiseh

## Project Developers
- Deirdre Jost
- Revisions by Steven Chiacchira and Aibak Aljadayah
